@@ -30,13 +30,24 @@ statsd_client = statsd.StatsClient(STATSD_CLIENT_HOST, STATSD_CLIENT_PORT)
 
 
 def set_entry_point(entry_point):
+    """
+        Sets the entry_point tag(request url, cli name etc) for all the metrics in collected through the apm library.
+        If the django middleware is being used you probably don't need to set this.
+        However in other cases where the middleware is not used e.g non-django applications or cli applications
+        it can be explicitly set using this function.
+        For http requests it needs to be the relative path of the api(e.g /api/auth),
+        for cli applications/library it can be custom set.
+    """
     global CURRENT_ENTRY_POINT
     CURRENT_ENTRY_POINT = entry_point
 
 
 def config_client(protocol='UDP', host=STATSD_CLIENT_HOST, port=STATSD_CLIENT_PORT, config_dict=None, tcp_timeout=1.0):
     """
-        Function to change the protocol, host and other settings used by the apm client at runtime to push metrics. Default is UDP
+        Function to change the protocol, host and other settings used by the apm client at runtime to push metrics.
+        Default protocol is UDP and it's suggested to be used in all cases as it's non blocking.
+        Other settings that can be changed are the common labels/tags for all metrics such as server_ip, server_name,
+        app_name.
 
         Attributes:
         ----------
@@ -51,7 +62,7 @@ def config_client(protocol='UDP', host=STATSD_CLIENT_HOST, port=STATSD_CLIENT_PO
                         All these keys will be available as a dropdown in grafana UI to filter metrics.
                         app_name key is required to be present.
 
-        timeout float: It is only applicable if protocol is TCP
+        tcp_timeout float: It is only applicable if protocol is TCP
     """
     global statsd_client
     if protocol == 'UDP':
@@ -76,6 +87,18 @@ def config_client(protocol='UDP', host=STATSD_CLIENT_HOST, port=STATSD_CLIENT_PO
 
 
 def add_label_to_metric_without_mapping(metric_name, labels_dict):
+    """
+        Add labels to the given metric_name uisng the Librato-style tags.
+        Attributes:
+        ----------
+        metric_name str: metric name string to which the tags are to be added
+        labels_dict dict: {
+                            <label/tag name>: <label_value>
+                        }
+
+                        For this key would be the label/tag name and the value will be its value.
+                        These key/value pairs will be converted to Prometheus labels.
+    """
     if METRIC_NO_MAPPING_LABEL_PREFIX not in metric_name:
         metric_name += METRIC_NO_MAPPING_LABEL_PREFIX
     else:
@@ -93,6 +116,9 @@ def add_label_to_metric_without_mapping(metric_name, labels_dict):
 
 
 def add_common_labels_to_metric(metric_name):
+    """
+        Adds common labels to the given metric.
+    """
     global CURRENT_ENTRY_POINT
     global SERVER_IP
     global SERVER_NAME
@@ -106,7 +132,7 @@ def add_common_labels_to_metric(metric_name):
     return metric_name
 
 
-def add_app_name_to_metric(metric_name, seperator=METRIC_NAME_SEPERATOR):
+def add_common_labels_to_all_metrics(metric_name, seperator=METRIC_NAME_SEPERATOR):
     global APP_NAME
     metric_name = add_label_to_metric_name(APP_NAME, metric_name)
     metric_name = add_common_labels_to_metric(metric_name)
@@ -118,62 +144,62 @@ def add_label_to_metric_name(label, metric_name, seperator=METRIC_LABEL_SEPERATO
 
 
 def create_http_request_latency_histogram_metric(metric_name=BASE_HTTP_LATENCY_METRIC_NAME):
-    metric_name = add_app_name_to_metric(metric_name)
+    metric_name = add_common_labels_to_all_metrics(metric_name)
     return metric_name
 
 
 def create_http_request_counter_metric_name(metric_name=BASE_HTTP_COUNTER_METRIC_NAME):
-    metric_name = add_app_name_to_metric(metric_name)
+    metric_name = add_common_labels_to_all_metrics(metric_name)
     return metric_name
 
 
 def create_http_request_latency_gauge_metric_name(metric_name=BASE_HTTP_LATENCY_GAUGE_METRIC_NAME):
-    metric_name = add_app_name_to_metric(metric_name)
+    metric_name = add_common_labels_to_all_metrics(metric_name)
     return metric_name
 
 
 def create_external_io_duration_metric_name(metric_name=BASE_EXTERNAL_IO_DURATION_METRIC_NAME):
-    metric_name = add_app_name_to_metric(metric_name)
+    metric_name = add_common_labels_to_all_metrics(metric_name)
     return metric_name
 
 
 def create_external_io_counter_metric_name(metric_name=BASE_EXTERNAL_IO_COUNTER_METRIC_NAME):
-    metric_name = add_app_name_to_metric(metric_name)
+    metric_name = add_common_labels_to_all_metrics(metric_name)
     return metric_name
 
 
 def create_external_io_exception_metric_name(metric_name=BASE_EXTERNAL_IO_EXCEPTION_METRIC):
-    metric_name = add_app_name_to_metric(metric_name)
+    metric_name = add_common_labels_to_all_metrics(metric_name)
     return metric_name
 
 
 def create_http_requests_exception_metric_name(metric_name=BASE_HTTP_EXCEPTION_METRIC):
-    metric_name = add_app_name_to_metric(metric_name)
+    metric_name = add_common_labels_to_all_metrics(metric_name)
     return metric_name
 
 
 def create_function_duration_metric_name(metric_name=BASE_FUNCTION_DURATION_METRIC_NAME):
-    metric_name = add_app_name_to_metric(metric_name)
+    metric_name = add_common_labels_to_all_metrics(metric_name)
     return metric_name
 
 
 def create_function_exception_metric_name(metric_name=BASE_FUNCTION_EXCEPTION_METRIC):
-    metric_name = add_app_name_to_metric(metric_name)
+    metric_name = add_common_labels_to_all_metrics(metric_name)
     return metric_name
 
 
 def create_http_function_latency_gauge_metric_name(metric_name=BASE_FUNCTION_LATENCY_GAUGE_METRIC):
-    metric_name = add_app_name_to_metric(metric_name)
+    metric_name = add_common_labels_to_all_metrics(metric_name)
     return metric_name
 
 
 def create_external_service_latency_gauge_metric_name(metric_name=BASE_EXTERNAL_IO_LATENCY_GAUGE_METRIC):
-    metric_name = add_app_name_to_metric(metric_name)
+    metric_name = add_common_labels_to_all_metrics(metric_name)
     return metric_name
 
 
 def create_bytes_metric_name(metric_name=BASE_BYTES_METRIC):
-    metric_name = add_app_name_to_metric(metric_name)
+    metric_name = add_common_labels_to_all_metrics(metric_name)
     return metric_name
 
 
@@ -188,10 +214,10 @@ def create_http_request_metrics(status_code, duration_ms, exception_type_class=N
         -----------
         status_code int: Can only be valid http status code (200, 599)
         duartion_ms float: Time taken for request in milliseconds
-         str: This string will be added to the start of each metric generated.
 
         Returns tuple: (<histogram_metric_name>, <guage_metric_name>, <exception_metric_name>)
-                        exception_metric_name is None is status code is other than range (500, 599) and no exception_type_class is provided
+                        exception_metric_name is None is status code is other than range (500, 599)
+                        and no exception_type_class is provided.
     """
     if status_code not in HTTP_REQUEST_STATUS_CODE_OPTIONS:
         logger.warning('status_code can only be one of {}'.format(
@@ -247,7 +273,7 @@ def create_http_request_counter_metric(status_code):
         request_counter_metric))
 
 
-def create_function_duration_metrics(duration_ms, function_name, host, status, exception_type_class=None):
+def create_function_duration_metrics(duration_ms, function_name, status, exception_type_class=None):
     """
         1. Pushes a Histogram based metric for functions runtime.
         2. If the status is 'error', creates a exception type counter with exception_type_class as label.
@@ -255,8 +281,9 @@ def create_function_duration_metrics(duration_ms, function_name, host, status, e
 
         Attributes:
         -----------
-        status str: can be either 'success' or 'error'
-        exception_type_class str: required if status is 'error'. Name of the exception type class
+        status str: can be either 'success' or 'error'.
+        function_name str: label value to be added added to the metrics generated with the name 'function_name'
+        exception_type_class str: required if status is 'error'. Name of the exception type class.
     """
     if status not in FUNCTION_STATUS_VALUES:
         logger.warning('status can only be one of [{}]'.format(
