@@ -3,8 +3,14 @@ import logging
 from .metrics import create_http_request_metrics, create_http_request_counter_metric
 from .metrics import config_client, set_entry_point
 from .constants import METRIC_APP_NAME_VAR_NAME
+from .helpers import get_generic_url_from_django_route_path
 from django.conf import settings
 
+try:
+   from django.core.urlresolvers import resolve
+except:
+    from django.urls import resolve
+
 
 def request_metrics_middleware(get_response):
     # One-time configuration and initialization.
@@ -13,7 +19,10 @@ def request_metrics_middleware(get_response):
         # Code to be executed for each request before
         # the view (and later middleware) are called.
         start_time_seconds = time.time()
-        set_entry_point(request.path)
+        entry_point = resolve(request.path)
+        entry_point = get_generic_url_from_django_route_path(request.path, entry_point.kwargs)
+        entry_point = request.method + ' ' + entry_point
+        set_entry_point(entry_point)
         try:
             if hasattr(settings, METRIC_APP_NAME_VAR_NAME):
                 app_name = getattr(settings, METRIC_APP_NAME_VAR_NAME)
